@@ -52,7 +52,8 @@ class Ticket:
             event=None,
             ticket_auth=None,
             event_date=None,
-            currency=None
+            currency=None,
+            external_card_ref=None
     ):
         self.id = id
         self.external_ticket_id = external_ticket_id
@@ -89,6 +90,7 @@ class Ticket:
         self.share_code = share_code
         self.redeemer_email = redeemer_email
         self.shared_at = shared_at
+        self.external_card_ref = external_card_ref
         if sharer_id:
             self._sharer = User.placeholder(id=sharer_id)
         else:
@@ -206,7 +208,8 @@ class Ticket:
             ticket_integration=None,
             venue=None,
             event=None,
-            currency=None
+            currency=None,
+            external_card_ref=None
         )
 
     @classmethod
@@ -251,7 +254,8 @@ class Ticket:
             ticket_integration=None,
             venue: Venue or str or int or None = None,
             event: Event or str or int or None = None,
-            currency: Currency or None = None
+            currency: Currency or None = None,
+            external_card_ref=None
     ):
         ticket = Ticket(
             id=None,
@@ -296,7 +300,8 @@ class Ticket:
             ticket_integration=ticket_integration,
             venue=venue,
             event=event,
-            currency=currency
+            currency=currency,
+            external_card_ref=external_card_ref
         )
         if isinstance(user, (str, int)):
             user = User.placeholder(id=user)
@@ -364,7 +369,7 @@ class Ticket:
             'price', 'status', 'can_share', 'sharer_email', 'redeemed_at', 'redeemer_id', 'share_code',
             'redeemer_email', 'parent_ticket', 'shared_at', 'legal_long_text', 'legal_short_text', 'map_url',
             'map_image_url', 'ticket_integration', 'entrance', 'row', 'section', 'price_code', 'external_customer_ref',
-            'venue', 'event', 'event_date', 'currency'
+            'venue', 'event', 'event_date', 'currency', 'external_card_ref'
         )
         for field in fields:
             if getattr(self, field) != getattr(other, field):
