@@ -50,7 +50,9 @@ from livestyled.schemas.team import TeamSchema
 from livestyled.schemas.ticket import TicketSchema
 from livestyled.schemas.ticket_auth import TicketAuthSchema
 from livestyled.schemas.ticket_integration import TicketIntegrationSchema
-from livestyled.schemas.user import UserCreateSchema, UserEmailSchema, UserInfoSchema, UserSchema, UserSSOSchema
+from livestyled.schemas.user import (
+    UserAliasSchema, UserAliasTypeSchema, UserCreateSchema, UserEmailSchema, UserInfoSchema, UserSchema, UserSSOSchema
+)
 from livestyled.schemas.venue import VenueSchema
 from livestyled.schemas.widget import WidgetSchema, WidgetVariationSchema
 
@@ -109,6 +111,8 @@ __all__ = [
     TicketAuthSchema,
     TicketIntegrationSchema,
     TicketSchema,
+    UserAliasSchema,
+    UserAliasTypeSchema,
     UserCreateSchema,
     UserEmailSchema,
     UserInfoSchema,
